#!/usr/bin/env python3
# -*- coding: UTF-8 -*-

import gi
import os
import getpass
import grp
import pwd
import subprocess

gi.require_version("Gtk", "3.0")
from gi.repository import Gtk

dirname = os.path.dirname(__file__)

class MyWindow(Gtk.Window):
    def __init__(self):
        Gtk.Window.__init__(self, title="VirtualBox Configurar Ext-Pack")
        self.set_wmclass("VirtualBox Configuarar Ext-Pack", "VirtualBox Configurar Ext-Pack")
        self.set_border_width(20)
        self.set_default_size(500, -1)
        filenameicon = os.path.join(dirname, 'img/virtualbox_icon.svg')
        self.set_icon_from_file(filenameicon)

        box = Gtk.Box(orientation = Gtk.Orientation.HORIZONTAL, spacing = 10)
        vbox = Gtk.Box(orientation = Gtk.Orientation.VERTICAL, spacing = 10)

        filenamelogo = os.path.join(dirname, 'img/virtualbox_logo.png')
        logo = Gtk.Image.new_from_file(filenamelogo)
        logo.set_valign(Gtk.Align.START)
        box.pack_start(logo, True, True, 10)
        box.pack_start(vbox, True, True, 5)
        labelnombre = Gtk.Label()
        labelnombre.set_markup('<big><b>VirtualBox</b></big>')
        labelnombre.set_halign(Gtk.Align.START)
        labelsubnombre = Gtk.Label()
        labelsubnombre.set_markup('<b>Configuración del pack de extensiones</b>')
        labelsubnombre.set_halign(Gtk.Align.START)
        labelinfo = Gtk.Label()
        labelinfo.set_markup('Esta herramienta configura el pack de extensiones de VirtualBox para el usuario que la ejecuta. Entre otras utilidades, se podrán hacer uso de los puertos USB dentro los sistemas operativos huéspedes que se ejecuten con VirtualBox. <b>Después de "Ejecutar" será necesario reiniciar el sistema para que los cambios tengan efecto.</b>')
        labelinfo.set_line_wrap(True)
        labelinfo.set_halign(Gtk.Align.START)
        self.boton = Gtk.Button(label = "Ejecutar")
        self.boton.set_halign(Gtk.Align.CENTER)
        self.boton.connect("clicked", self.ejecutar_ext_pack_config)
        self.labelresultado = Gtk.Label()
        self.labelresultado.set_halign(Gtk.Align.START)
        vbox.pack_start(labelnombre, True, True, 0)
        vbox.pack_start(labelsubnombre, True, True, 0)
        vbox.pack_start(labelinfo, True, True, 0)
        vbox.pack_start(self.boton, False, False, 0)
        vbox.pack_start(self.labelresultado, True, True, 0)
        self.add(box)
        self.update_info_config()

    def ejecutar_ext_pack_config(self, widget):
        subprocess.run(["sudo", "/usr/bin/vboxextpackconfig.sh", getpass.getuser()])
        self.update_info_config()


    def update_info_config(self):
        username = getpass.getuser()
        groups = [g.gr_name for g in grp.getgrall() if username in g.gr_mem]
        gid = pwd.getpwnam(username).pw_gid
        groups.append(grp.getgrgid(gid).gr_name)
        vboxgroup = "vboxusers"
        if vboxgroup in groups:
            self.labelresultado.set_markup("<span color='green'>El paquete de extensiones ya está configurado</span>")
            self.boton.set_sensitive(False)
        else:
            self.labelresultado.set_markup("<span color='red'>El paquete de extensiones todavía no está configurado</span>")


win = MyWindow()
win.connect("destroy", Gtk.main_quit)
win.show_all()
Gtk.main()
